==> MediaWikiLanguageExtensionBundle-2014.07.tar.bz2: extensions/cldr/CldrNames/CldrNamesTi.php <==
<?php

$languageNames = array(
	'af' => 'አፍሪቃንሰኛ',
	'am' => 'አምሐረኛ',
	'ar' => 'ዓረበኛ',
	'az' => 'አዜርባይጃንኛ',
	'be' => 'ቤላራሻኛ',
	'bg' => 'ቡልጋሪኛ',
	'bh' => 'ቢሃሪ',
	'bn' => 'በንጋሊኛ',
	'br' => 'ብሬቶን',
	'bs' => 'ቦስኒያን',
	'ca' => 'ካታላን',
	'cs' => 'ቼክኛ',
	'cy' => 'ወልሽ',
	'da' => 'ዴኒሽ',
	'de' => 'ጀርመን',
	'el' => 'ግሪከኛ',
	'en' => 'እንግሊዝኛ',
	'eo' => 'ኤስፐራንቶ',
	'es' => 'ስፓኒሽ',
	'et' => 'ኤስቶኒአን',
	'eu' => 'ባስክኛ',
	'fa' => 'ፐርሲያኛ',
	'fi' => 'ፊኒሽ',
	'fil' => 'ታጋሎገኛ',
	'fo' => 'ፋሮኛ',
	'fr' => 'ፈረንሳይኛ',
	'fy' => 'ፍሪሰኛ',
	'ga' => 'አይሪሽ',
	'gd' => 'እስኮትስ ጌልክኛ',
	'gl' => 'ጋለቪኛ',
	'gn' => 'ጓራኒ',
	'gu' => 'ጉጃራቲኛ',
	'he' => 'ዕብራስጥ',
	'hi' => 'ሕንደኛ',
	'hr' => 'ክሮሽያንኛ',
	'hu' => 'ሀንጋሪኛ',
	'ia' => 'ኢንቴር ቋንቋ',
	'id' => 'እንዶኑሲኛ',
	'is' => 'አይስላንደኛ',
	'it' => 'ጣሊያንኛ',
	'ja' => 'ጃፓንኛ',
	'jv' => 'ጃቫንኛ',
	'ka' => 'ጊዮርጊያኛ',
	'kn' => 'ካማደኛ',
	'ko' => 'ኮሪያኛ',
	'ku' => 'ኩርድሽ',
	'ky' => 'ኪሩጋዚ',
	'la' => 'ላቲንኛ',
	'lt' => 'ሊቱአኒየን',
	'lv' => 'ላቲቪያን',
	'mk' => 'ማክዶኒኛ',
	'ml' => 'ማላያላምኛ',
	'mr' => 'ማራቲኛ',
	'ms' => 'ማላይኛ',
	'mt' => 'ማልቲስኛ',
	'ne' => 'ኔፖሊኛ',
	'nl' => 'ደች',
	'nn' => 'ኖርዌይኛ (ናይ ኝኖርስክ)',
	'no' => 'ኖርዌጂያን',
	'oc' => 'ኦኪታንኛ',
	'or' => 'ኦሪያ',
	'pa' => 'ፑንጃቢኛ',
	'pl' => 'ፖሊሽ',
	'ps' => 'ፓሽቶ',
	'pt' => 'ፖርቱጋሊኛ',
	'pt-br' => 'ፖርቱጋልኛ (ናይ ብራዚል)',
	'pt-pt' => 'ፖርቱጋልኛ (ናይ ፖርቱጋል)',
	'ro' => 'ሮማኒያን',
	'ru' => 'ራሽኛ',
	'sh' => 'ሰርቦ- ክሮዊታን',
	'si' => 'ስንሃልኛ',
	'sk' => 'ስሎቨክኛ',
	'sl' => 'ስቁቪኛ',
	'sq' => 'አልቤኒኛ',
	'sr' => 'ሰርቢኛ',
	'st' => 'ሰሴቶ',
	'su' => 'ሱዳንኛ',
	'sv' => 'ስዊድንኛ',
	'sw' => 'ሰዋሂሊኛ',
	'ta' => 'ታሚልኛ',
	'te' => 'ተሉጉኛ',
	'th' => 'ታይኛ',
	'ti' => 'ትግርኛ',
	'tk' => 'ናይ ቱርኪ ሰብዓይ (ቱርካዊ)',
	'tlh' => 'ክሊንግኦንኛ',
	'tr' => 'ቱርከኛ',
	'tw' => 'ትዊ',
	'uk' => 'ዩክረኒኛ',
	'ur' => 'ኡርዱኛ',
	'uz' => 'ኡዝበክኛ',
	'vi' => 'ቪትናምኛ',
	'xh' => 'ዞሳኛ',
	'yi' => 'ዪዲሽ',
	'zu' => 'ዙሉኛ',
);

$currencyNames = array(
	'BRL' => 'የብራዚል ሪል',
	'CNY' => 'የቻይና ዩአን ረንሚንቢ',
	'ETB' => 'የኢትዮጵያ ብር',
	'EUR' => 'አውሮ',
	'GBP' => 'የእንግሊዝ ፓውንድ ስተርሊንግ',
	'INR' => 'የሕንድ ሩፒ',
	'JPY' => 'የጃፓን የን',
	'RUB' => 'የራሻ ሩብል',
	'USD' => 'የአሜሪካን ዶላር',
);

$currencySymbols = array(
	'ETB' => 'Br',
);

$countryNames = array(
	'AD' => 'አንዶራ',
	'AE' => 'የተባበሩት አረብ ኤምሬትስ',
	'AF' => 'አፍጋኒስታን',
	'AG' => 'አንቲጓ እና ባሩዳ',
	'AI' => 'አንጉኢላ',
	'AL' => 'አልባኒያ',
	'AM' => 'አርሜኒያ',
	'AN' => 'ኔዘርላንድስ አንቲልስ',
	'AO' => 'አንጐላ',
	'AQ' => 'አንታርክቲካ',
	'AR' => 'አርጀንቲና',
	'AS' => 'የአሜሪካ ሳሞአ',
	'AT' => 'ኦስትሪያ',
	'AU' => 'አውስትሬሊያ',
	'AW' => 'አሩባ',
	'AX' => 'የአላንድ ደሴቶች',
	'AZ' => 'አዘርባጃን',
	'BA' => 'ቦስኒያ እና ሄርዞጎቪኒያ',
	'BB' => 'ባርቤዶስ',
	'BD' => 'ባንግላዲሽ',
	'BE' => 'ቤልጄም',
	'BF' => 'ቡርኪና ፋሶ',
	'BG' => 'ቡልጌሪያ',
	'BH' => 'ባህሬን',
	'BI' => 'ብሩንዲ',
	'BJ' => 'ቤኒን',
	'BM' => 'ቤርሙዳ',
	'BN' => 'ብሩኒ',
	'BO' => 'ቦሊቪያ',
	'BR' => 'ብራዚል',
	'BS' => 'ባሃማስ',
	'BT' => 'ቡህታን',
	'BV' => 'የቦውቬት ደሴት',
	'BW' => 'ቦትስዋና',
	'BY' => 'ቤላሩስ',
	'BZ' => 'ቤሊዘ',
	'CA' => 'ካናዳ',
	'CC' => 'ኮኮስ ኬሊንግ ደሴቶች',
	'CD' => 'ኮንጎ',
	'CF' => 'የመካከለኛው አፍሪካ ሪፐብሊክ',
	'CG' => 'ኮንጐ',
	'CH' => 'ስዊዘርላንድ',
	'CI' => 'ኮት ዲቯር',
	'CK' => 'ኩክ ደሴቶች',
	'CL' => 'ቺሊ',
	'CM' => 'ካሜሩን',
	'CN' => 'ቻይና',
	'CO' => 'ኮሎምቢያ',
	'CR' => 'ኮስታ ሪካ',
	'CU' => 'ኩባ',
	'CV' => 'ኬፕ ቬርዴ',
	'CX' => 'የገና ደሴቶች',
	'CY' => 'ሳይፕረስ',
	'CZ' => 'ቼክ ሪፑብሊክ',
	'DE' => 'ጀርመን',
	'DJ' => 'ጂቡቲ',
	'DK' => 'ዴንማርክ',
	'DM' => 'ዶሚኒካ',
	'DO' => 'ዶሚኒክ ሪፑብሊክ',
	'DZ' => 'አልጄሪያ',
	'EC' => 'ኢኳዶር',
	'EE' => 'ኤስቶኒያ',
	'EG' => 'ግብጽ',
	'EH' => 'ምዕራባዊ ሳህራ',
	'ER' => 'ኤርትራ',
	'ES' => 'ስፔን',
	'ET' => 'ኢትዮጵያ',
	'FI' => 'ፊንላንድ',
	'FJ' => 'ፊጂ',
	'FK' => 'የፎልክላንድ ደሴቶች',
	'FM' => 'ሚክሮኔዢያ',
	'FO' => 'የፋሮይ ደሴቶች',
	'FR' => 'ፈረንሳይ',
	'GA' => 'ጋቦን',
	'GB' => 'እንግሊዝ',
	'GD' => 'ግሬናዳ',
	'GE' => 'ጆርጂያ',
	'GF' => 'የፈረንሳይ ጉዊአና',
	'GH' => 'ጋና',
	'GI' => 'ጊብራልታር',
	'GL' => 'ግሪንላንድ',
	'GM' => 'ጋምቢያ',
	'GN' => 'ጊኒ',
	'GP' => 'ጉዋደሉፕ',
	'GQ' => 'ኢኳቶሪያል ጊኒ',
	'GR' => 'ግሪክ',
	'GS' => 'ደቡብ ጆርጂያ እና የደቡድ ሳንድዊች ደሴቶች',
	'GT' => 'ጉዋቲማላ',
	'GU' => 'ጉዋም',
	'GW' => 'ቢሳዎ',
	'GY' => 'ጉያና',
	'HK' => 'ሆንግ ኮንግ',
	'HM' => 'የኧርድ እና የማክዶናልድ ደሴቶች',
	'HN' => 'ሆንዱራስ',
	'HR' => 'ክሮኤሽያ',
	'HT' => 'ሀይቲ',
	'HU' => 'ሀንጋሪ',
	'ID' => 'ኢንዶኔዢያ',
	'IE' => 'አየርላንድ',
	'IL' => 'እስራኤል',
	'IN' => 'ህንድ',
	'IO' => 'የብሪታኒያ ህንድ ውቂያኖስ ግዛት',
	'IQ' => 'ኢራቅ',
	'IR' => 'ኢራን',
	'IS' => 'አይስላንድ',
	'IT' => 'ጣሊያን',
	'JM' => 'ጃማይካ',
	'JO' => 'ጆርዳን',
	'JP' => 'ጃፓን',
	'KE' => 'ኬንያ',
	'KH' => 'ካምቦዲያ',
	'KI' => 'ኪሪባቲ',
	'KM' => 'ኮሞሮስ',
	'KN' => 'ቅዱስ ኪትስ እና ኔቪስ',
	'KP' => 'ሰሜን ኮሪያ',
	'KR' => 'ደቡብ ኮሪያ',
	'KW' => 'ክዌት',
	'KY' => 'ካይማን ደሴቶች',
	'LA' => 'ላኦስ',
	'LB' => 'ሊባኖስ',
	'LC' => 'ሴንት ሉቺያ',
	'LI' => 'ሊችተንስታይን',
	'LK' => 'ሲሪላንካ',
	'LR' => 'ላይቤሪያ',
	'LS' => 'ሌሶቶ',
	'LT' => 'ሊቱዌኒያ',
	'LU' => 'ሉክሰምበርግ',
	'LV' => 'ላትቪያ',
	'LY' => 'ሊቢያ',
	'MA' => 'ሞሮኮ',
	'MC' => 'ሞናኮ',
	'MD' => 'ሞልዶቫ',
	'MG' => 'ማዳጋስካር',
	'MH' => 'ማርሻል አይላንድ',
	'MK' => 'ማከዶኒያ',
	'ML' => 'ማሊ',
	'MM' => 'ማያንማር',
	'MN' => 'ሞንጎሊያ',
	'MO' => 'ማካዎ',
	'MP' => 'የሰሜናዊ ማሪያና ደሴቶች',
	'MQ' => 'ማርቲኒክ',
	'MR' => 'ሞሪቴኒያ',
	'MS' => 'ሞንትሴራት',
	'MT' => 'ማልታ',
	'MU' => 'ማሩሸስ',
	'MV' => 'ማልዲቭስ',
	'MW' => 'ማላዊ',
	'MX' => 'ሜክሲኮ',
	'MY' => 'ማሌዢያ',
	'MZ' => 'ሞዛምቢክ',
	'NA' => 'ናሚቢያ',
	'NC' => 'ኒው ካሌዶኒያ',
	'NE' => 'ኒጀር',
	'NF' => 'ኖርፎልክ ደሴት',
	'NG' => 'ናይጄሪያ',
	'NI' => 'ኒካራጓ',
	'NL' => 'ኔዘርላንድ',
	'NO' => 'ኖርዌ',
	'NP' => 'ኔፓል',
	'NR' => 'ናኡሩ',
	'NU' => 'ኒኡይ',
	'NZ' => 'ኒው ዚላንድ',
	'OM' => 'ኦማን',
	'PA' => 'ፓናማ',
	'PE' => 'ፔሩ',
	'PF' => 'የፈረንሳይ ፖሊኔዢያ',
	'PG' => 'ፓፑዋ ኒው ጊኒ',
	'PH' => 'ፊሊፒንስ',
	'PK' => 'ፓኪስታን',
	'PL' => 'ፖላንድ',
	'PM' => 'ቅዱስ ፒዬር እና ሚኩኤሎን',
	'PN' => 'ፒትካኢርን',
	'PR' => 'ፖርታ ሪኮ',
	'PS' => 'የፍልስጤም ግዛት',
	'PT' => 'ፖርቱጋል',
	'PW' => 'ፓላው',
	'PY' => 'ፓራጓይ',
	'QA' => 'ኳታር',
	'QO' => 'ወጣ ያለ ኦሽኒያ',
	'RE' => 'ሪዩኒየን',
	'RO' => 'ሮሜኒያ',
	'RU' => 'ራሺያ',
	'RW' => 'ሩዋንዳ',
	'SA' => 'ሳውድአረቢያ',
	'SB' => 'ሰሎሞን ደሴት',
	'SC' => 'ሲሼልስ',
	'SD' => 'ሱዳን',
	'SE' => 'ስዊድን',
	'SG' => 'ሲንጋፖር',
	'SH' => 'ሴንት ሄለና',
	'SI' => 'ስሎቬኒያ',
	'SJ' => 'የስቫልባርድ እና ዣን ማየን ደሴቶች',
	'SK' => 'ስሎቫኪያ',
	'SL' => 'ሴራሊዮን',
	'SM' => 'ሳን ማሪኖ',
	'SN' => 'ሴኔጋል',
	'SO' => 'ሱማሌ',
	'SR' => 'ሱሪናም',
	'ST' => 'ሳኦ ቶሜ እና ፕሪንሲፔ',
	'SV' => 'ኤል ሳልቫዶር',
	'SY' => 'ሲሪያ',
	'SZ' => 'ሱዋዚላንድ',
	'TC' => 'የቱርኮችና የካኢኮስ ደሴቶች',
	'TD' => 'ቻድ',
	'TF' => 'የፈረንሳይ ደቡባዊ ግዛቶች',
	'TG' => 'ቶጐ',
	'TH' => 'ታይላንድ',
	'TJ' => 'ታጃኪስታን',
	'TK' => 'ቶክላው',
	'TL' => 'ምስራቅ ቲሞር',
	'TM' => 'ቱርክሜኒስታን',
	'TN' => 'ቱኒዚያ',
	'TO' => 'ቶንጋ',
	'TR' => 'ቱርክ',
	'TT' => 'ትሪኒዳድ እና ቶባጎ',
	'TV' => 'ቱቫሉ',
	'TW' => 'ታይዋን',
	'TZ' => 'ታንዛኒያ',
	'UA' => 'ዩክሬን',
	'UG' => 'ዩጋንዳ',
	'UM' => 'የአሜሪካ ራቅ ያሉ አናሳ ደሴቶች',
	'US' => 'አሜሪካ',
	'UY' => 'ኡራጓይ',
	'UZ' => 'ዩዝበኪስታን',
	'VA' => 'ቫቲካን',
	'VC' => 'ቅዱስ ቪንሴንት እና ግሬናዲንስ',
	'VE' => 'ቬንዙዌላ',
	'VG' => 'የእንግሊዝ ድንግል ደሴቶች',
	'VI' => 'የአሜሪካ ቨርጂን ደሴቶች',
	'VN' => 'ቬትናም',
	'VU' => 'ቫኑአቱ',
	'WF' => 'ዋሊስ እና ፉቱና ደሴቶች',
	'WS' => 'ሳሞአ',
	'YE' => 'የመን',
	'YT' => 'ሜይኦቴ',
	'ZA' => 'ደቡብ አፍሪካ',
	'ZM' => 'ዛምቢያ',
	'ZW' => 'ዚምቧቤ',
);

==> MediaWikiLanguageExtensionBundle-2017.01.tar.bz2: extensions/cldr/CldrNames/CldrNamesTi.php <==
<?php

$languageNames = [
	'af' => 'አፍሪቃንሰኛ',
	'am' => 'አምሐረኛ',
	'ar' => 'ዓረበኛ',
	'az' => 'አዜርባይጃንኛ',
	'be' => 'ቤላራሻኛ',
	'bg' => 'ቡልጋሪኛ',
	'bn' => 'በንጋሊኛ',
	'br' => 'ብሬቶን',
	'bs' => 'ቦስኒያን',
	'ca' => 'ካታላን',
	'cs' => 'ቼክኛ',
	'cy' => 'ወልሽ',
	'da' => 'ዴኒሽ',
	'de' => 'ጀርመን',
	'el' => 'ግሪከኛ',
	'en' => 'እንግሊዝኛ',
	'eo' => 'ኤስፐራንቶ',
	'es' => 'ስፓኒሽ',
	'et' => 'ኤስቶኒአን',
	'eu' => 'ባስክኛ',
	'fa' => 'ፐርሲያኛ',
	'fi' => 'ፊኒሽ',
	'fil' => 'ታጋሎገኛ',
	'fo' => 'ፋሮኛ',
	'fr' => 'ፈረንሳይኛ',
	'fy' => 'ፍሪሰኛ',
	'ga' => 'አይሪሽ',
	'gd' => 'እስኮትስ ጌልክኛ',
	'gl' => 'ጋለቪኛ',
	'gn' => 'ጓራኒ',
	'gu' => 'ጉጃራቲኛ',
	'he' => 'ዕብራስጥ',
	'hi' => 'ሕንደኛ',
	'hr' => 'ክሮሽያንኛ',
	'hu' => 'ሀንጋሪኛ',
	'ia' => 'ኢንቴር ቋንቋ',
	'id' => 'እንዶኑሲኛ',
	'is' => 'አይስላንደኛ',
	'it' => 'ጣሊያንኛ',
	'ja' => 'ጃፓንኛ',
	'jv' => 'ጃቫንኛ',
	'ka' => 'ጊዮርጊያኛ',
	'kn' => 'ካማደኛ',
	'ko' => 'ኮሪያኛ',
	'ku' => 'ኩርድሽ',
	'ky' => 'ኪሩጋዚ',
	'la' => 'ላቲንኛ',
	'lt' => 'ሊቱአኒየን',
	'lv' => 'ላቲቪያን',
	'mk' => 'ማክዶኒኛ',
	'ml' => 'ማላያላምኛ',
	'mr' => 'ማራቲኛ',
	'ms' => 'ማላይኛ',
	'mt' => 'ማልቲስኛ',
	'ne' => 'ኔፖሊኛ',
	'nl' => 'ደች',
	'nn' => 'ኖርዌይኛ (ናይ ኝኖርስክ)',
	'no' => 'ኖርዌጂያን',
	'oc' => 'ኦኪታንኛ',
	'or' => 'ኦሪያ',
	'pa' => 'ፑንጃቢኛ',
	'pl' => 'ፖሊሽ',
	'ps' => 'ፓሽቶ',
	'pt' => 'ፖርቱጋሊኛ',
	'pt-br' => 'ፖርቱጋልኛ (ናይ ብራዚል)',
	'pt-pt' => 'ፖርቱጋልኛ (ናይ ፖርቱጋል)',
	'ro' => 'ሮማኒያን',
	'ru' => 'ራሽኛ',
	'sh' => 'ሰርቦ- ክሮዊታን',
	'si' => 'ስንሃልኛ',
	'sk' => 'ስሎቨክኛ',
	'sl' => 'ስቁቪኛ',
	'sq' => 'አልቤኒኛ',
	'sr' => 'ሰርቢኛ',
	'st' => 'ሰሴቶ',
	'su' => 'ሱዳንኛ',
	'sv' => 'ስዊድንኛ',
	'sw' => 'ሰዋሂሊኛ',
	'ta' => 'ታሚልኛ',
	'te' => 'ተሉጉኛ',
	'th' => 'ታይኛ',
	'ti' => 'ትግርኛ',
	'tk' => 'ናይ ቱርኪ ሰብዓይ (ቱርካዊ)',
	'tlh' => 'ክሊንግኦንኛ',
	'tr' => 'ቱርከኛ',
	'tw' => 'ትዊ',
	'uk' => 'ዩክረኒኛ',
	'ur' => 'ኡርዱኛ',
	'uz' => 'ኡዝበክኛ',
	'vi' => 'ቪትናምኛ',
	'xh' => 'ዞሳኛ',
	'yi' => 'ዪዲሽ',
	'zu' => 'ዙሉኛ',
];

$currencyNames = [
	'BRL' => 'የብራዚል ሪል',
	'CNY' => 'የቻይና ዩአን ረንሚንቢ',
	'ETB' => 'የኢትዮጵያ ብር',
	'EUR' => 'አውሮ',
	'GBP' => 'የእንግሊዝ ፓውንድ ስተርሊንግ',
	'INR' => 'የሕንድ ሩፒ',
	'JPY' => 'የጃፓን የን',
	'RUB' => 'የራሻ ሩብል',
	'USD' => 'የአሜሪካን ዶላር',
];

$currencySymbols = [
	'ETB' => 'Br',
];

$countryNames = [
	'AD' => 'አንዶራ',
	'AE' => 'የተባበሩት አረብ ኤምሬትስ',
	'AF' => 'አፍጋኒስታን',
	'AG' => 'አንቲጓ እና ባሩዳ',
	'AI' => 'አንጉኢላ',
	'AL' => 'አልባኒያ',
	'AM' => 'አርሜኒያ',
	'AO' => 'አንጐላ',
	'AQ' => 'አንታርክቲካ',
	'AR' => 'አርጀንቲና',
	'AS' => 'የአሜሪካ ሳሞአ',
	'AT' => 'ኦስትሪያ',
	'AU' => 'አውስትሬሊያ',
	'AW' => 'አሩባ',
	'AX' => 'የአላንድ ደሴቶች',
	'AZ' => 'አዘርባጃን',
	'BA' => 'ቦስኒያ እና ሄርዞጎቪኒያ',
	'BB' => 'ባርቤዶስ',
	'BD' => 'ባንግላዲሽ',
	'BE' => 'ቤልጄም',
	'BF' => 'ቡርኪና ፋሶ',
	'BG' => 'ቡልጌሪያ',
	'BH' => 'ባህሬን',
	'BI' => 'ብሩንዲ',
	'BJ' => 'ቤኒን',
	'BM' => 'ቤርሙዳ',
	'BN' => 'ብሩኒ',
	'BO' => 'ቦሊቪያ',
	'BR' => 'ብራዚል',
	'BS' => 'ባሃማስ',
	'BT' => 'ቡህታን',
	'BV' => 'የቦውቬት ደሴት',
	'BW' => 'ቦትስዋና',
	'BY' => 'ቤላሩስ',
	'BZ' => 'ቤሊዘ',
	'CA' => 'ካናዳ',
	'CC' => 'ኮኮስ ኬሊንግ ደሴቶች',
	'CD' => 'ኮንጎ',
	'CF' => 'የመካከለኛው አፍሪካ ሪፐብሊክ',
	'CG' => 'ኮንጐ',
	'CH' => 'ስዊዘርላንድ',
	'CI' => 'ኮት ዲቯር',
	'CK' => 'ኩክ ደሴቶች',
	'CL' => 'ቺሊ',
	'CM' => 'ካሜሩን',
	'CN' => 'ቻይና',
	'CO' => 'ኮሎምቢያ',
	'CR' => 'ኮስታ ሪካ',
	'CU' => 'ኩባ',
	'CV' => 'ኬፕ ቬርዴ',
	'CX' => 'የገና ደሴቶች',
	'CY' => 'ሳይፕረስ',
	'CZ' => 'ቼክ ሪፑብሊክ',
	'DE' => 'ጀርመን',
	'DJ' => 'ጂቡቲ',
	'DK' => 'ዴንማርክ',
	'DM' => 'ዶሚኒካ',
	'DO' => 'ዶሚኒክ ሪፑብሊክ',
	'DZ' => 'አልጄሪያ',
	'EC' => 'ኢኳዶር',
	'EE' => 'ኤስቶኒያ',
	'EG' => 'ግብጽ',
	'EH' => 'ምዕራባዊ ሳህራ',
	'ER' => 'ኤርትራ',
	'ES' => 'ስፔን',
	'ET' => 'ኢትዮጵያ',
	'FI' => 'ፊንላንድ',
	'FJ' => 'ፊጂ',
	'FK' => 'የፎልክላንድ ደሴቶች',
	'FM' => 'ሚክሮኔዢያ',
	'FO' => 'የፋሮይ ደሴቶች',
	'FR' => 'ፈረንሳይ',
	'GA' => 'ጋቦን',
	'GB' => 'እንግሊዝ',
	'GD' => 'ግሬናዳ',
	'GE' => 'ጆርጂያ',
	'GF' => 'የፈረንሳይ ጉዊአና',
	'GH' => 'ጋና',
	'GI' => 'ጊብራልታር',
	'GL' => 'ግሪንላንድ',
	'GM' => 'ጋምቢያ',
	'GN' => 'ጊኒ',
	'GP' => 'ጉዋደሉፕ',
	'GQ' => 'ኢኳቶሪያል ጊኒ',
	'GR' => 'ግሪክ',
	'GS' => 'ደቡብ ጆርጂያ እና የደቡድ ሳንድዊች ደሴቶች',
	'GT' => 'ጉዋቲማላ',
	'GU' => 'ጉዋም',
	'GW' => 'ቢሳዎ',
	'GY' => 'ጉያና',
	'HK' => 'ሆንግ ኮንግ',
	'HM' => 'የኧርድ እና የማክዶናልድ ደሴቶች',
	'HN' => 'ሆንዱራስ',
	'HR' => 'ክሮኤሽያ',
	'HT' => 'ሀይቲ',
	'HU' => 'ሀንጋሪ',
	'ID' => 'ኢንዶኔዢያ',
	'IE' => 'አየርላንድ',
	'IL' => 'እስራኤል',
	'IN' => 'ህንድ',
	'IO' => 'የብሪታኒያ ህንድ ውቂያኖስ ግዛት',
	'IQ' => 'ኢራቅ',
	'IR' => 'ኢራን',
	'IS' => 'አይስላንድ',
	'IT' => 'ጣሊያን',
	'JM' => 'ጃማይካ',
	'JO' => 'ጆርዳን',
	'JP' => 'ጃፓን',
	'KE' => 'ኬንያ',
	'KH' => 'ካምቦዲያ',
	'KI' => 'ኪሪባቲ',
	'KM' => 'ኮሞሮስ',
	'KN' => 'ቅዱስ ኪትስ እና ኔቪስ',
	'KP' => 'ሰሜን ኮሪያ',
	'KR' => 'ደቡብ ኮሪያ',
	'KW' => 'ክዌት',
	'KY' => 'ካይማን ደሴቶች',
	'LA' => 'ላኦስ',
	'LB' => 'ሊባኖስ',
	'LC' => 'ሴንት ሉቺያ',
	'LI' => 'ሊችተንስታይን',
	'LK' => 'ሲሪላንካ',
	'LR' => 'ላይቤሪያ',
	'LS' => 'ሌሶቶ',
	'LT' => 'ሊቱዌኒያ',
	'LU' => 'ሉክሰምበርግ',
	'LV' => 'ላትቪያ',
	'LY' => 'ሊቢያ',
	'MA' => 'ሞሮኮ',
	'MC' => 'ሞናኮ',
	'MD' => 'ሞልዶቫ',
	'MG' => 'ማዳጋስካር',
	'MH' => 'ማርሻል አይላንድ',
	'MK' => 'ማከዶኒያ',
	'ML' => 'ማሊ',
	'MM' => 'ማያንማር',
	'MN' => 'ሞንጎሊያ',
	'MO' => 'ማካዎ',
	'MP' => 'የሰሜናዊ ማሪያና ደሴቶች',
	'MQ' => 'ማርቲኒክ',
	'MR' => 'ሞሪቴኒያ',
	'MS' => 'ሞንትሴራት',
	'MT' => 'ማልታ',
	'MU' => 'ማሩሸስ',
	'MV' => 'ማልዲቭስ',
	'MW' => 'ማላዊ',
	'MX' => 'ሜክሲኮ',
	'MY' => 'ማሌዢያ',
	'MZ' => 'ሞዛምቢክ',
	'NA' => 'ናሚቢያ',
	'NC' => 'ኒው ካሌዶኒያ',
	'NE' => 'ኒጀር',
	'NF' => 'ኖርፎልክ ደሴት',
	'NG' => 'ናይጄሪያ',
	'NI' => 'ኒካራጓ',
	'NL' => 'ኔዘርላንድ',
	'NO' => 'ኖርዌ',
	'NP' => 'ኔፓል',
	'NR' => 'ናኡሩ',
	'NU' => 'ኒኡይ',
	'NZ' => 'ኒው ዚላንድ',
	'OM' => 'ኦማን',
	'PA' => 'ፓናማ',
	'PE' => 'ፔሩ',
	'PF' => 'የፈረንሳይ ፖሊኔዢያ',
	'PG' => 'ፓፑዋ ኒው ጊኒ',
	'PH' => 'ፊሊፒንስ',
	'PK' => 'ፓኪስታን',
	'PL' => 'ፖላንድ',
	'PM' => 'ቅዱስ ፒዬር እና ሚኩኤሎን',
	'PN' => 'ፒትካኢርን',
	'PR' => 'ፖርታ ሪኮ',
	'PS' => 'የፍልስጤም ግዛት',
	'PT' => 'ፖርቱጋል',
	'PW' => 'ፓላው',
	'PY' => 'ፓራጓይ',
	'QA' => 'ኳታር',
	'QO' => 'ወጣ ያለ ኦሽኒያ',
	'RE' => 'ሪዩኒየን',
	'RO' => 'ሮሜኒያ',
	'RU' => 'ራሺያ',
	'RW' => 'ሩዋንዳ',
	'SA' => 'ሳውድአረቢያ',
	'SB' => 'ሰሎሞን ደሴት',
	'SC' => 'ሲሼልስ',
	'SD' => 'ሱዳን',
	'SE' => 'ስዊድን',
	'SG' => 'ሲንጋፖር',
	'SH' => 'ሴንት ሄለና',
	'SI' => 'ስሎቬኒያ',
	'SJ' => 'የስቫልባርድ እና ዣን ማየን ደሴቶች',
	'SK' => 'ስሎቫኪያ',
	'SL' => 'ሴራሊዮን',
	'SM' => 'ሳን ማሪኖ',
	'SN' => 'ሴኔጋል',
	'SO' => 'ሱማሌ',
	'SR' => 'ሱሪናም',
	'ST' => 'ሳኦ ቶሜ እና ፕሪንሲፔ',
	'SV' => 'ኤል ሳልቫዶር',
	'SY' => 'ሲሪያ',
	'SZ' => 'ሱዋዚላንድ',
	'TC' => 'የቱርኮችና የካኢኮስ ደሴቶች',
	'TD' => 'ቻድ',
	'TF' => 'የፈረንሳይ ደቡባዊ ግዛቶች',
	'TG' => 'ቶጐ',
	'TH' => 'ታይላንድ',
	'TJ' => 'ታጃኪስታን',
	'TK' => 'ቶክላው',
	'TL' => 'ምስራቅ ቲሞር',
	'TM' => 'ቱርክሜኒስታን',
	'TN' => 'ቱኒዚያ',
	'TO' => 'ቶንጋ',
	'TR' => 'ቱርክ',
	'TT' => 'ትሪኒዳድ እና ቶባጎ',
	'TV' => 'ቱቫሉ',
	'TW' => 'ታይዋን',
	'TZ' => 'ታንዛኒያ',
	'UA' => 'ዩክሬን',
	'UG' => 'ዩጋንዳ',
	'UM' => 'የአሜሪካ ራቅ ያሉ አናሳ ደሴቶች',
	'US' => 'አሜሪካ',
	'UY' => 'ኡራጓይ',
	'UZ' => 'ዩዝበኪስታን',
	'VA' => 'ቫቲካን',
	'VC' => 'ቅዱስ ቪንሴንት እና ግሬናዲንስ',
	'VE' => 'ቬንዙዌላ',
	'VG' => 'የእንግሊዝ ድንግል ደሴቶች',
	'VI' => 'የአሜሪካ ቨርጂን ደሴቶች',
	'VN' => 'ቬትናም',
	'VU' => 'ቫኑአቱ',
	'WF' => 'ዋሊስ እና ፉቱና ደሴቶች',
	'WS' => 'ሳሞአ',
	'YE' => 'የመን',
	'YT' => 'ሜይኦቴ',
	'ZA' => 'ደቡብ አፍሪካ',
	'ZM' => 'ዛምቢያ',
	'ZW' => 'ዚምቧቤ',
];
